@@ -155,132 +155,7 @@
 #include <stdio.h>
 #include <time.h>
 #include <wchar.h>
-
-/* BeOS 5 has the functions but no <wctype.h>.  */
-#if HAVE_WCTYPE_H
-# include <wctype.h>
-#endif
-/* FreeBSD 4.4 to 4.11 has <wctype.h> but lacks the functions.
-   Assume all 12 functions are implemented the same way, or not at all.  */
-#if !defined iswalnum && !HAVE_ISWCNTRL
-static inline int
-iswalnum (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? (wc >= '0' && wc <= '9') || ((wc & ~0x20) >= 'A' && (wc & ~0x20) <= 'Z')
-	  : 0);
-}
-# define iswalnum iswalnum
-#endif
-#if !defined iswalpha && !HAVE_ISWCNTRL
-static inline int
-iswalpha (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? (wc & ~0x20) >= 'A' && (wc & ~0x20) <= 'Z'
-	  : 0);
-}
-# define iswalpha iswalpha
-#endif
-#if !defined iswblank && !HAVE_ISWCNTRL
-static inline int
-iswblank (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc == ' ' || wc == '\t'
-	  : 0);
-}
-# define iswblank iswblank
-#endif
-#if !defined iswcntrl && !HAVE_ISWCNTRL
-static inline int
-iswcntrl (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? (wc & ~0x1f) == 0 || wc == 0x7f
-	  : 0);
-}
-# define iswcntrl iswcntrl
-#endif
-#if !defined iswdigit && !HAVE_ISWCNTRL
-static inline int
-iswdigit (wint_t wc)
-{
-  return (wc >= '0' && wc <= '9');
-}
-# define iswdigit iswdigit
-#endif
-#if !defined iswgraph && !HAVE_ISWCNTRL
-static inline int
-iswgraph (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc >= '!' && wc <= '~'
-	  : 1);
-}
-# define iswgraph iswgraph
-#endif
-#if !defined iswlower && !HAVE_ISWCNTRL
-static inline int
-iswlower (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc >= 'a' && wc <= 'z'
-	  : 0);
-}
-# define iswlower iswlower
-#endif
-#if !defined iswprint && !HAVE_ISWCNTRL
-static inline int
-iswprint (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc >= ' ' && wc <= '~'
-	  : 1);
-}
-# define iswprint iswprint
-#endif
-#if !defined iswpunct && !HAVE_ISWCNTRL
-static inline int
-iswpunct (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc >= '!' && wc <= '~'
-	    && !((wc >= '0' && wc <= '9')
-		 || ((wc & ~0x20) >= 'A' && (wc & ~0x20) <= 'Z'))
-	  : 1);
-}
-# define iswpunct iswpunct
-#endif
-#if !defined iswspace && !HAVE_ISWCNTRL
-static inline int
-iswspace (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc == ' ' || wc == '\t'
-	    || wc == '\n' || wc == '\v' || wc == '\f' || wc == '\r'
-	  : 0);
-}
-# define iswspace iswspace
-#endif
-#if !defined iswupper && !HAVE_ISWCNTRL
-static inline int
-iswupper (wint_t wc)
-{
-  return (wc >= 0 && wc < 128
-	  ? wc >= 'A' && wc <= 'Z'
-	  : 0);
-}
-# define iswupper iswupper
-#endif
-#if !defined iswxdigit && !HAVE_ISWCNTRL
-static inline int
-iswxdigit (wint_t wc)
-{
-  return (wc >= '0' && wc <= '9') || ((wc & ~0x20) >= 'A' && (wc & ~0x20) <= 'F');
-}
-# define iswxdigit iswxdigit
-#endif
+#include <wctype.h>
 
 #include "wcwidth.h"
 
@@ -385,18 +260,18 @@ mb_width_aux (wint_t wc)
 
 /* Copying a character.  */
 static inline void
-mb_copy (mbchar_t *new, const mbchar_t *old)
+mb_copy (mbchar_t *new_mbc, const mbchar_t *old_mbc)
 {
-  if (old->ptr == &old->buf[0])
+  if (old_mbc->ptr == &old_mbc->buf[0])
     {
-      memcpy (&new->buf[0], &old->buf[0], old->bytes);
-      new->ptr = &new->buf[0];
+      memcpy (&new_mbc->buf[0], &old_mbc->buf[0], old_mbc->bytes);
+      new_mbc->ptr = &new_mbc->buf[0];
     }
   else
-    new->ptr = old->ptr;
-  new->bytes = old->bytes;
-  if ((new->wc_valid = old->wc_valid))
-    new->wc = old->wc;
+    new_mbc->ptr = old_mbc->ptr;
+  new_mbc->bytes = old_mbc->bytes;
+  if ((new_mbc->wc_valid = old_mbc->wc_valid))
+    new_mbc->wc = old_mbc->wc;
 }
 
 
@@ -430,7 +305,7 @@ mb_copy (mbchar_t *new, const mbchar_t *old)
 /* The character set is ISO-646, not EBCDIC. */
 # define IS_BASIC_ASCII 1
 
-extern unsigned int is_basic_table[];
+extern const unsigned int is_basic_table[];
 
 static inline bool
 is_basic (char c)
