@@ -635,14 +635,17 @@ extern int re_exec (const char *);
 #  endif
 # endif
 #endif
-/* gcc 3.1 and up support the [restrict] syntax.  */
-#ifndef __restrict_arr
-# if (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 1)) \
-     && !defined __GNUG__
-#  define __restrict_arr __restrict
-# else
-#  define __restrict_arr
-# endif
+/* gcc 3.1 and up support the [restrict] syntax.  Don't trust
+   sys/cdefs.h's definition of __restrict_arr, though, as it
+   mishandles gcc -ansi -pedantic.  */
+#undef __restrict_arr
+#if ((199901L <= __STDC_VERSION__					\
+      || ((3 < __GNUC__ || (3 == __GNUC__ && 1 <= __GNUC_MINOR__))	\
+	  && !__STRICT_ANSI__))						\
+     && !defined __GNUG__)
+# define __restrict_arr __restrict
+#else
+# define __restrict_arr
 #endif
 
 /* POSIX compatibility.  */
