@@ -31,7 +31,6 @@
 #include <string.h>
 #include <sys/types.h>
 #include <errno.h>
-#include <time.h>
 
 #include "prelude-error.h"
 #include "idmef.h"
@@ -246,6 +245,17 @@ uint64_t prelude_hton64(uint64_t val)
 }
 
 
+uint32_t prelude_htonf(float fval)
+{
+        union {
+                float fval;
+                uint32_t ival;
+        } val;
+                
+        val.fval = fval;
+
+        return htonl(val.ival);
+}
 
 
 static void normalize_path(char *path) 
