@@ -27,12 +27,22 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <sys/time.h>
 #include <pthread.h>
 #include <errno.h>
 #include <signal.h>
 #include <assert.h>
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #include "prelude-thread.h"
 #include "prelude-list.h"
 #include "prelude-inttypes.h"
