@@ -31,10 +31,20 @@
 #include <string.h>
 #include <sys/types.h>
 #include <dirent.h>
-#include <sys/time.h>
 #include <unistd.h>
 #include <assert.h>
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #include "ltdl.h"
 
 #include "prelude-log.h"
